<?php

namespace FiloBlu\Popup\Block;

use Magento\Cms\Model\ResourceModel\AbstractCollection;

class Popup extends \Magento\Framework\View\Element\Template
{
  const CUSTOM_MEDIA_PATH = "filoblu/popup";

  protected $_popupFactory;
  protected $_filterProvider;
  protected $_popupData;

  public function __construct(
      \Magento\Framework\View\Element\Template\Context $context,
      \FiloBlu\Popup\Model\PopupFactory $popupFactory,
      \Magento\Cms\Model\Template\FilterProvider $filterProvider,
      array $data = []
  ) {
      parent::__construct($context, $data);
      $this->_popupFactory = $popupFactory;
      $this->_filterProvider = $filterProvider;
  }


  public function currentStoreId()
      {
          $currentStore = $this->_storeManager->getStore();
          return $currentStore->getId();
      }


  public function getPopupData()
  {   
    if ($this->getPopupId() && !$this->_popupData)
    {
      $model = $this->_popupFactory->create();
      $model->load($this->getPopupId());
      $this->_popupData = $model->getData();
    }

    return $this->_popupData;
  }

  public function getCookieDuration()
  {
      return $this->getPopupData()["cookie_duration"];
  }

  public function isEnabled()
  {
    return $this->getPopupData()["enabled"];
  }

  public function getTitle()
  {
    return $this->getPopupData()["title"];
  }

  public function getDescription()
  {
    return $this->getPopupData()["description"];
  }

  public function getImage()
  {
    return $this->getPopupData()["image"];
  }

  public function isImageLinkEnabled()
  {
    return $this->getPopupData()["link_image"];
  }

  public function getLink()
  {
    return $this->getPopupData()["link"];
  }

  public function getPopupDeplay()
  {
    return $this->getPopupData()["delay"];
  }

  public function getCtaText()
  {
    return $this->getPopupData()["link_text"];
  }

  public function getCssStyle()
  {
    return $this->getPopupData()["css_style"];
  }

  public function getStoreIds()
  {
      return explode(',',$this->getPopupData()["store_ids"]);
  }

  public function getImageUrl($imageName)
  {
    return $this->_storeManager->getStore()->getBaseUrl(
        \Magento\Framework\UrlInterface::URL_TYPE_MEDIA
    ) . self::CUSTOM_MEDIA_PATH . "/".$imageName;
  }

  public function getFilteredContent($string)
  {
       return $this->_filterProvider->getBlockFilter()->setStoreId($this->_storeManager->getStore()->getId())->filter($string);
  }

   public function _toHtml()
   {
        if ((in_array($this->currentStoreId(), $this->getStoreIds()) || in_array(0, $this->getStoreIds())) && $this->isEnabled() ){
           // $this->setTemplate('FiloBlu_Popup::popup.phtml');
            return parent::_toHtml();
        } else {
            return "";
        }
   }

}
